@@ -23,8 +23,16 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
+from .annotation import AnnotationMixin
+from .bookmark import BookmarkMixin
 from .element import Element, PropDef, register_element_class
-from .named_range import NamedRange
+from .form import FormMixin
+from .mixin_named_range import NRMixin
+from .note import NoteMixin
+from .office_forms import OfficeFormsMixin
+from .reference import ReferenceMixin
+from .section import SectionMixin
+from .tracked_changes import TrackedChangesMixin
 
 if TYPE_CHECKING:
     from .table import Table
@@ -117,116 +125,6 @@ class Body(Element):
     get_sheet = get_table
 
 
-class NRMixin(Body):
-    """Mixin for Named Range access.
-
-    Used by the following classes: Chart, Drawing, Preentation, Spreadsheet, Text.
-    """
-
-    def get_named_ranges(self) -> list[NamedRange]:
-        """Return the list of Name Ranges of the document.
-
-        Named ranges global to the document.
-
-        Returns: list of NamedRange
-        """
-        named_ranges = self.get_elements(
-            "descendant::table:named-expressions/table:named-range"
-        )
-        return named_ranges  # type: ignore[return-value]
-
-    def get_named_range(self, name: str) -> NamedRange | None:
-        """Return the Name Range of the specified name.
-
-        Named ranges global to the document.
-
-        Args:
-
-            name -- str
-
-        Returns: NamedRange or None
-        """
-        named_range = self.get_elements(
-            f'descendant::table:named-expressions/table:named-range[@table:name="{name}"][1]'
-        )
-        if named_range:
-            return named_range[0]  # type: ignore[return-value]
-        else:
-            return None
-
-    def append_named_range(self, named_range: NamedRange) -> None:
-        """Append the named range to the document.
-
-        An existing named range of same name is replaced.
-
-        Named ranges global to the document.
-
-        Args:
-
-            named_range --  NamedRange
-        """
-        named_expressions = self.get_element("table:named-expressions")
-        if not named_expressions:
-            named_expressions = Element.from_tag("table:named-expressions")
-            self._Element__append(named_expressions)  # type: ignore[attr-defined]
-        # exists ?
-        current = named_expressions.get_element(
-            f'table:named-range[@table:name="{named_range.name}"][1]'
-        )
-        if current:
-            named_expressions.delete(current)
-        named_expressions._Element__append(named_range)  # type: ignore[attr-defined]
-
-    def set_named_range(
-        self,
-        name: str,
-        crange: str | tuple | list,
-        table_name: str,
-        usage: str | None = None,
-    ) -> None:
-        """Create a Named Range element and insert it in the document.
-
-        An existing named range of same name is replaced.
-
-        Args:
-
-            name -- str, name of the named range
-
-            crange -- str or tuple of int, cell or area coordinate
-
-            table_name -- str, name of the table
-
-            usage -- None or 'print-range', 'filter', 'repeat-column', 'repeat-row'
-        """
-        name = name.strip()
-        if not name:
-            raise ValueError("Name required")
-        table_name = table_name.strip()
-        if not table_name:
-            raise ValueError("Table name required")
-        named_range = NamedRange(name, crange, table_name, usage)
-        self.append_named_range(named_range)
-
-    def delete_named_range(self, name: str) -> None:
-        """Delete the Named Range of specified name from the document.
-
-        Named ranges global to the document.
-
-        Args:
-
-            name -- str
-        """
-        named_range = self.get_named_range(name)
-        if not named_range:
-            return
-        named_range.delete()
-        named_expressions = self.get_element("table:named-expressions")
-        element = named_expressions._Element__element  # type: ignore[union-attr]
-        children = list(element.iterchildren())
-        if not children:
-            self.delete(named_expressions)
-
-
 class Chart(NRMixin, Body):
     """Root of the Chart document content, "office:chart"."""
 
@@ -262,14 +160,25 @@ class Presentation(NRMixin, Body):
     _properties: tuple[PropDef, ...] = ()
 
 
-class Spreadsheet(NRMixin, Body):
+class Spreadsheet(AnnotationMixin, NRMixin, Body):
     """Root of the Spreadsheet document content, "office:spreadsheet"."""
 
     _tag: str = "office:spreadsheet"
     _properties: tuple[PropDef, ...] = ()
 
 
-class Text(NRMixin, Body):
+class Text(
+    NRMixin,
+    FormMixin,
+    TrackedChangesMixin,
+    OfficeFormsMixin,
+    SectionMixin,
+    ReferenceMixin,
+    BookmarkMixin,
+    AnnotationMixin,
+    NoteMixin,
+    Body,
+):
     """Root of the Text document content, "office:text"."""
 
     _tag: str = "office:text"
