@@ -33,9 +33,11 @@ from datetime import timedelta
 from decimal import ConversionSyntax, Decimal, InvalidOperation
 from typing import TYPE_CHECKING, Any
 
+from .annotation import AnnotationMixin
 from .datatype import Boolean, Date, DateTime, Duration
 from .element import Element, register_element_class_list
 from .element_typed import ElementTyped
+from .section import SectionMixin
 
 _int = builtins.int
 _float = builtins.float
@@ -44,7 +46,7 @@ if TYPE_CHECKING:
     from .style import Style
 
 
-class Cell(ElementTyped):
+class Cell(SectionMixin, AnnotationMixin, ElementTyped):
     """A cell of a table, "table:table-cell" and "table:covered-table-cell"."""
 
     _tag = "table:table-cell"
@@ -432,7 +434,7 @@ class Cell(ElementTyped):
     def _set_repeated(self, repeated: _int | None) -> None:
         """Internal only.
 
-        Set the numnber of times the cell is repeated, or None to delete.
+        Set the number of times the cell is repeated, or None to delete.
         Without changing cache.
         """
         if repeated is None or repeated < 2:
