@@ -193,7 +193,7 @@ def container_from_template(template: str | Path | io.BytesIO) -> Container:
         ) as template_path:
             template_container.open(template_path)
     else:
-        # custome template
+        # custom template
         template_container.open(template)
     # Return a copy of the template container
     container = template_container.clone
@@ -233,7 +233,7 @@ class Document(MDDocument):
             Meaning of “empty”: these documents are copies of the default
             templates documents provided with this library, which, as templates,
             are not really empty. It may be useful to clear the newly created
-            document: document.body.clear(), or adjust meta informations like
+            document: document.body.clear(), or adjust meta information like
             description or default language: document.meta.language = 'fr-FR'
 
         If the argument is not a known template type, or is a Path,
@@ -251,7 +251,7 @@ class Document(MDDocument):
             # eager conversion
             target = bytes_to_str(target)
         if target is None:
-            # empty document, you probably don't wnat this.
+            # empty document, you probably don't want this.
             self.container = Container()
             return
         if isinstance(target, Path):
@@ -343,7 +343,7 @@ class Document(MDDocument):
         the real path, e.g. content.xml, and return a dedicated object with its
         own API.
 
-        path formated as URI, so always use '/' separator
+        path formatted as URI, so always use '/' separator
         """
         if not self.container:
             raise ValueError("Empty Container")
@@ -364,7 +364,7 @@ class Document(MDDocument):
         """Set the bytes of the given part. The path is relative to the
         archive, e.g. "Pictures/1003200258912EB1C3.jpg".
 
-        path formated as URI, so always use '/' separator
+        path formatted as URI, so always use '/' separator
         """
         if not self.container:
             raise ValueError("Empty Container")
@@ -569,7 +569,7 @@ class Document(MDDocument):
         return "".join(result)
 
     def get_formated_meta(self) -> str:
-        """Return meta informations as text, with some formatting.
+        """Return meta information as text, with some formatting.
 
         (Redirection to new implementation for compatibility.)
         """
@@ -600,7 +600,7 @@ class Document(MDDocument):
         """Insert a file from a path or a file-like object in the container.
 
         Return the full path to reference in the content. The internal name
-        of the file in the Picture/ folder is gnerated by a hash function.
+        of the file in the Picture/ folder is generated by a hash function.
 
         Args:
 
@@ -1040,7 +1040,7 @@ class Document(MDDocument):
             try:
                 name = style.name  # type: ignore[attr-defined]
             except AttributeError:
-                print("Syle error:")
+                print("Style error:")
                 print(style.__class__)
                 print(style.serialize())
                 raise
