@@ -32,7 +32,7 @@ from datetime import datetime, timedelta
 from decimal import Decimal
 from functools import cache
 from re import search
-from typing import TYPE_CHECKING, Any, NamedTuple
+from typing import TYPE_CHECKING, Any, NamedTuple, cast
 
 from lxml.etree import Element as lxml_Element
 from lxml.etree import XPath, _Element, fromstring, tostring
@@ -50,24 +50,14 @@ from .utils import (
 )
 
 if TYPE_CHECKING:
-    from .annotation import Annotation, AnnotationEnd
     from .body import Body
-    from .bookmark import Bookmark, BookmarkEnd, BookmarkStart
     from .draw_page import DrawPage
     from .frame import Frame
     from .header import Header
     from .image import DrawImage
     from .link import Link
     from .list import List
-    from .note import Note
     from .paragraph import Paragraph, Span
-    from .reference import (
-        Reference,
-        ReferenceMark,
-        ReferenceMarkEnd,
-        ReferenceMarkStart,
-    )
-    from .section import Section
     from .shapes import (
         ConnectorShape,
         DrawGroup,
@@ -82,7 +72,6 @@ if TYPE_CHECKING:
         TextChange,
         TextChangeEnd,
         TextChangeStart,
-        TrackedChanges,
     )
     from .user_field import UserDefined, UserFieldDecl, UserFieldDecls
     from .variable import VarDecls, VarSet
@@ -887,7 +876,7 @@ class Element(MDBase):
         return match.start()
 
     def search_first(self, pattern: str) -> tuple[int, int] | None:
-        """Return the start and end position of the first occurence of the
+        """Return the start and end position of the first occurrence of the
         regex pattern in the text content of the element.
 
         Result is tuples of start and end position, or None.
@@ -968,7 +957,7 @@ class Element(MDBase):
     ) -> int:
         """Replace the pattern with the given text, or delete if text is an
         empty string, and return the number of replacements. By default, only
-        return the number of occurences that would be replaced.
+        return the number of occurrences that would be replaced.
 
         It cannot replace patterns found across several element, like a word
         split into two consecutive spans.
@@ -1180,6 +1169,15 @@ class Element(MDBase):
             elements = [element.__element for element in odf_elements]
             current.extend(elements)
 
+    def _xml_append(self, element: Element) -> None:
+        """Append the XML _element to  self._element."""
+        self.__element.append(element.__element)
+
+    @property
+    def _xml_element(self) -> _Element:
+        """Return the underlying XML element."""
+        return self.__element
+
     def __append(self, str_or_element: str | Element) -> None:
         """Insert element or text in the last position."""
 
@@ -1362,56 +1360,6 @@ class Element(MDBase):
     def svg_description(self, description: str) -> None:
         self._set_inner_text("svg:desc", description)
 
-    # Sections
-
-    def get_sections(
-        self,
-        style: str | None = None,
-        content: str | None = None,
-    ) -> list[Section]:
-        """Return all the sections that match the criteria.
-
-        Args:
-
-            style -- str
-
-            content -- str regex
-
-        Returns: list of Section
-        """
-        return self._filtered_elements(
-            "text:section", text_style=style, content=content
-        )  # type: ignore[return-value]
-
-    @property
-    def sections(
-        self,
-    ) -> list[Section]:
-        """Return all the sections.
-
-        Returns: list of Section
-        """
-        return self.get_elements("text:section")  # type: ignore[return-value]
-
-    def get_section(
-        self,
-        position: int = 0,
-        content: str | None = None,
-    ) -> Section | None:
-        """Return the section that matches the criteria.
-
-        Args:
-
-            position -- int
-
-            content -- str regex
-
-        Returns: Section or None if not found
-        """
-        return self._filtered_element(
-            "descendant::text:section", position, content=content
-        )  # type: ignore[return-value]
-
     # Paragraphs
 
     def get_paragraphs(
@@ -1585,9 +1533,12 @@ class Element(MDBase):
 
         Returns: list of List
         """
-        return self._filtered_elements(
-            "descendant::text:list", text_style=style, content=content
-        )  # type: ignore[return-value]
+        return cast(
+            "list[List]",
+            self._filtered_elements(
+                "descendant::text:list", text_style=style, content=content
+            ),
+        )
 
     @property
     def lists(self) -> list[List]:
@@ -1595,7 +1546,7 @@ class Element(MDBase):
 
         Returns: list of List
         """
-        return self.get_elements("descendant::text:list")  # type: ignore[return-value]
+        return cast("list[List]", self.get_elements("descendant::text:list"))
 
     def get_list(
         self,
@@ -1762,167 +1713,6 @@ class Element(MDBase):
             "descendant::draw:image", position, url=url, content=content
         )  # type: ignore[return-value]
 
-    # Named Range
-
-    # Notes
-
-    def get_notes(
-        self,
-        note_class: str | None = None,
-        content: str | None = None,
-    ) -> list[Note]:
-        """Return all the notes that match the criteria.
-
-        Args:
-
-            note_class -- 'footnote' or 'endnote'
-
-            content -- str regex
-
-        Returns: list of Note
-        """
-        return self._filtered_elements(
-            "descendant::text:note", note_class=note_class, content=content
-        )  # type: ignore[return-value]
-
-    def get_note(
-        self,
-        position: int = 0,
-        note_id: str | None = None,
-        note_class: str | None = None,
-        content: str | None = None,
-    ) -> Note | None:
-        """Return the note that matches the criteria.
-
-        Args:
-
-            position -- int
-
-            note_id -- str
-
-            note_class -- 'footnote' or 'endnote'
-
-            content -- str regex
-
-        Returns: Note or None if not found
-        """
-        return self._filtered_element(
-            "descendant::text:note",
-            position,
-            text_id=note_id,
-            note_class=note_class,
-            content=content,
-        )  # type: ignore[return-value]
-
-    # Annotations
-
-    def get_annotations(
-        self,
-        creator: str | None = None,
-        start_date: datetime | None = None,
-        end_date: datetime | None = None,
-        content: str | None = None,
-    ) -> list[Annotation]:
-        """Return all the annotations that match the criteria.
-
-        Args:
-
-            creator -- str
-
-            start_date -- datetime instance
-
-            end_date --  datetime instance
-
-            content -- str regex
-
-        Returns: list of Annotation
-        """
-        annotations: list[Annotation] = []
-        for annotation in self._filtered_elements(
-            "descendant::office:annotation", content=content
-        ):
-            if creator is not None and creator != annotation.dc_creator:  # type: ignore[attr-defined]
-                continue
-            date = annotation.date  # type: ignore[attr-defined]
-            # date never None: recreated if missing
-            if date is None:  # pragma: no cover
-                continue
-            if start_date is not None and date < start_date:
-                continue
-            if end_date is not None and date >= end_date:
-                continue
-            annotations.append(annotation)  # type: ignore[arg-type]
-        return annotations
-
-    def get_annotation(
-        self,
-        position: int = 0,
-        creator: str | None = None,
-        start_date: datetime | None = None,
-        end_date: datetime | None = None,
-        content: str | None = None,
-        name: str | None = None,
-    ) -> Annotation | None:
-        """Return the annotation that matches the criteria.
-
-        Args:
-
-            position -- int
-
-            creator -- str
-
-            start_date -- datetime instance
-
-            end_date -- datetime instance
-
-            content -- str regex
-
-            name -- str
-
-        Returns: Annotation or None if not found
-        """
-        if name is not None:
-            return self._filtered_element(
-                "descendant::office:annotation", 0, office_name=name
-            )  # type: ignore[return-value]
-        annotations: list[Annotation] = self.get_annotations(
-            creator=creator, start_date=start_date, end_date=end_date, content=content
-        )
-        if not annotations:
-            return None
-        try:
-            return annotations[position]
-        except IndexError:
-            return None
-
-    def get_annotation_ends(self) -> list[AnnotationEnd]:
-        """Return all the annotation ends.
-
-        Returns: list of AnnotationEnd
-        """
-        return self._filtered_elements(
-            "descendant::office:annotation-end",
-        )  # type: ignore[return-value]
-
-    def get_annotation_end(
-        self,
-        position: int = 0,
-        name: str | None = None,
-    ) -> AnnotationEnd | None:
-        """Return the annotation end that matches the criteria.
-
-        Args:
-
-            position -- int
-
-            name -- str
-
-        Returns: AnnotationEnd or None if not found
-        """
-        return self._filtered_element(
-            "descendant::office:annotation-end", position, office_name=name
-        )  # type: ignore[return-value]
-
     # office:names
 
     def get_office_names(self) -> list[str]:
@@ -2237,251 +2027,6 @@ class Element(MDBase):
             content=content,
         )  # type: ignore[return-value]
 
-    # Bookmarks
-
-    def get_bookmarks(self) -> list[Bookmark]:
-        """Return all the bookmarks.
-
-        Returns: list of Bookmark
-        """
-        return self._filtered_elements(
-            "descendant::text:bookmark",
-        )  # type: ignore[return-value]
-
-    def get_bookmark(
-        self,
-        position: int = 0,
-        name: str | None = None,
-    ) -> Bookmark | None:
-        """Return the bookmark that matches the criteria.
-
-        Args:
-
-            position -- int
-
-            name -- str
-
-        Returns: Bookmark or None if not found
-        """
-        return self._filtered_element(
-            "descendant::text:bookmark", position, text_name=name
-        )  # type: ignore[return-value]
-
-    def get_bookmark_starts(self) -> list[BookmarkStart]:
-        """Return all the bookmark starts.
-
-        Returns: list of BookmarkStart
-        """
-        return self._filtered_elements(
-            "descendant::text:bookmark-start",
-        )  # type: ignore[return-value]
-
-    def get_bookmark_start(
-        self,
-        position: int = 0,
-        name: str | None = None,
-    ) -> BookmarkStart | None:
-        """Return the bookmark start that matches the criteria.
-
-        Args:
-
-            position -- int
-
-            name -- str
-
-        Returns: BookmarkStart or None if not found
-        """
-        return self._filtered_element(
-            "descendant::text:bookmark-start", position, text_name=name
-        )  # type: ignore[return-value]
-
-    def get_bookmark_ends(self) -> list[BookmarkEnd]:
-        """Return all the bookmark ends.
-
-        Returns: list of BookmarkEnd
-        """
-        return self._filtered_elements(
-            "descendant::text:bookmark-end",
-        )  # type: ignore[return-value]
-
-    def get_bookmark_end(
-        self,
-        position: int = 0,
-        name: str | None = None,
-    ) -> BookmarkEnd | None:
-        """Return the bookmark end that matches the criteria.
-
-        Args:
-
-            position -- int
-
-            name -- str
-
-        Returns: BookmarkEnd or None if not found
-        """
-        return self._filtered_element(
-            "descendant::text:bookmark-end", position, text_name=name
-        )  # type: ignore[return-value]
-
-    # Reference marks
-
-    def get_reference_marks_single(self) -> list[ReferenceMark]:
-        """Return all the reference marks. Search only the tags
-        text:reference-mark.
-        Consider using : get_reference_marks()
-
-        Returns: list of ReferenceMark
-        """
-        return self._filtered_elements(
-            "descendant::text:reference-mark",
-        )  # type: ignore[return-value]
-
-    def get_reference_mark_single(
-        self,
-        position: int = 0,
-        name: str | None = None,
-    ) -> ReferenceMark | None:
-        """Return the reference mark that matches the criteria. Search only the
-        tags text:reference-mark.
-        Consider using : get_reference_mark()
-
-        Args:
-
-            position -- int
-
-            name -- str
-
-        Returns: ReferenceMark or None if not found
-        """
-        return self._filtered_element(
-            "descendant::text:reference-mark", position, text_name=name
-        )  # type: ignore[return-value]
-
-    def get_reference_mark_starts(self) -> list[ReferenceMarkStart]:
-        """Return all the reference mark starts. Search only the tags
-        text:reference-mark-start.
-        Consider using : get_reference_marks()
-
-        Returns: list of ReferenceMarkStart
-        """
-        return self._filtered_elements(
-            "descendant::text:reference-mark-start",
-        )  # type: ignore[return-value]
-
-    def get_reference_mark_start(
-        self,
-        position: int = 0,
-        name: str | None = None,
-    ) -> ReferenceMarkStart | None:
-        """Return the reference mark start that matches the criteria. Search
-        only the tags text:reference-mark-start.
-        Consider using : get_reference_mark()
-
-        Args:
-
-            position -- int
-
-            name -- str
-
-        Returns: ReferenceMarkStart or None if not found
-        """
-        return self._filtered_element(
-            "descendant::text:reference-mark-start", position, text_name=name
-        )  # type: ignore[return-value]
-
-    def get_reference_mark_ends(self) -> list[ReferenceMarkEnd]:
-        """Return all the reference mark ends. Search only the tags
-        text:reference-mark-end.
-        Consider using : get_reference_marks()
-
-        Returns: list of ReferenceMarkEnd
-        """
-        return self._filtered_elements(
-            "descendant::text:reference-mark-end",
-        )  # type: ignore[return-value]
-
-    def get_reference_mark_end(
-        self,
-        position: int = 0,
-        name: str | None = None,
-    ) -> ReferenceMarkEnd | None:
-        """Return the reference mark end that matches the criteria. Search only
-        the tags text:reference-mark-end.
-        Consider using : get_reference_marks()
-
-        Args:
-
-            position -- int
-
-            name -- str
-
-        Returns: ReferenceMarkEnd or None if not found
-        """
-        return self._filtered_element(
-            "descendant::text:reference-mark-end", position, text_name=name
-        )  # type: ignore[return-value]
-
-    def get_reference_marks(self) -> list[ReferenceMark | ReferenceMarkStart]:
-        """Return all the reference marks, either single position reference
-        (text:reference-mark) or start of range reference (text:reference-mark-
-        start).
-
-        Returns: list of ReferenceMark or ReferenceMarkStart
-        """
-        return self._filtered_elements(
-            "descendant::text:reference-mark-start | descendant::text:reference-mark"
-        )  # type: ignore[return-value]
-
-    def get_reference_mark(
-        self,
-        position: int = 0,
-        name: str | None = None,
-    ) -> ReferenceMark | ReferenceMarkStart | None:
-        """Return the reference mark that match the criteria. Either single
-        position reference mark (text:reference-mark) or start of range
-        reference (text:reference-mark-start).
-
-        Args:
-
-            position -- int
-
-            name -- str
-
-        Returns: ReferenceMark or ReferenceMarkStart or None if not found
-        """
-        if name:
-            request = (
-                f"descendant::text:reference-mark-start"
-                f'[@text:name="{name}"] '
-                f"| descendant::text:reference-mark"
-                f'[@text:name="{name}"]'
-            )
-            return self._filtered_element(
-                request,
-                position=0,
-            )  # type: ignore[return-value]
-        request = (
-            "descendant::text:reference-mark-start | descendant::text:reference-mark"
-        )
-        return self._filtered_element(request, position)  # type: ignore[return-value]
-
-    def get_references(self, name: str | None = None) -> list[Reference]:
-        """Return all the references (text:reference-ref). If name is provided,
-        returns the references of that name.
-
-        Args:
-
-            name -- str or None
-
-        Returns: list of Reference
-        """
-        if name is None:
-            return self._filtered_elements(
-                "descendant::text:reference-ref",
-            )  # type: ignore[return-value]
-        request = f'descendant::text:reference-ref[@text:ref-name="{name}"]'
-        return self._filtered_elements(request)  # type: ignore[return-value]
-
     # Shapes elements
 
     # Groups
@@ -2756,21 +2301,6 @@ class Element(MDBase):
 
     # Tracked changes and text change
 
-    def get_tracked_changes(self) -> TrackedChanges | None:
-        """Return the tracked-changes part in the text body.
-
-        Returns: TrackedChanges or None
-        """
-        return self.get_element("//text:tracked-changes")  # type: ignore[return-value]
-
-    @property
-    def tracked_changes(self) -> Element | None:
-        """Return the tracked-changes part in the text body.
-
-        Returns: Element or None
-        """
-        return self.get_tracked_changes()
-
     def get_changes_ids(self) -> list[Element | EText]:
         """Return a list of ids that refers to a change region in the tracked
         changes list.
