@@ -29,13 +29,14 @@ from datetime import date as dtdate
 from datetime import datetime, timedelta
 from decimal import Decimal
 from operator import itemgetter
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, cast
 
-from .datatype import Boolean, Date, DateTime, Duration
+from .datatype import DateTime, Duration
 from .element import Element
 from .meta_auto_reload import MetaAutoReload
 from .meta_hyperlink_behaviour import MetaHyperlinkBehaviour
 from .meta_template import MetaTemplate
+from .meta_user_defined import MetaUserDefined
 from .mixin_dc_creator import DcCreatorMixin
 from .mixin_dc_date import DcDateMixin
 from .utils import is_RFC3066, to_str
@@ -66,6 +67,15 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
         """Return the body of the "meta.xml" part."""
         return self._get_body()
 
+    @property
+    def odf_office_version(self) -> str:
+        """Return the "office:version" value of the document."""
+        odm = self.get_element("//office:document-meta")
+        # "office:version" sould be always present
+        if odm:
+            return odm.get_attribute_string("office:version") or ""
+        return ""  # pragma: nocover
+
     def get_title(self) -> str | None:
         """Get the title of the document.
 
@@ -73,7 +83,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         (Also available as "self.title" property.)
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
         """
         element = self.get_element("//dc:title")
         if element is None:
@@ -101,7 +111,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
     def title(self) -> str | None:
         """Get or set the title of the document <dc:title>.
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
         """
         return self.get_title()
 
@@ -114,7 +124,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         (Also available as "self.description" property.)
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
         """
         element = self.get_element("//dc:description")
         if element is None:
@@ -145,7 +155,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
     def description(self) -> str | None:
         """Get or set the description of a document <dc:description>.
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
         """
         return self.get_description()
 
@@ -158,7 +168,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         (Also available as "self.subject" property.)
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
         """
         element = self.get_element("//dc:subject")
         if element is None:
@@ -184,7 +194,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
     def subject(self) -> str | None:
         """Get or set the subject of a document <dc:subject>.
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
         """
         return self.get_subject()
 
@@ -200,7 +210,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         (Also available as "self.language" property.)
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
 
         Example::
 
@@ -248,7 +258,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
         To set globally the default language, prefer the
         Document.language property.
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
         """
         return self.get_language()
 
@@ -261,7 +271,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         (Also available as "self.creation_date" property.)
 
-        Returns: datetime (or None if inexistant)
+        Returns: datetime (or None if inexistent)
         """
         element = self.get_element("//meta:creation-date")
         if element is None:
@@ -295,7 +305,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         If provided datetime is None, use current time.
 
-        Returns: datetime (or None if inexistant)
+        Returns: datetime (or None if inexistent)
         """
         return self.get_creation_date()
 
@@ -310,7 +320,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         If provided datetime is None, use current time.
 
-        Returns: datetime (or None if inexistant)
+        Returns: datetime (or None if inexistent)
         """
         element = self.get_element("//meta:print-date")
         if element is None:
@@ -406,7 +416,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         (Also available as "self.initial_creator" property.)
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
 
         Example::
 
@@ -441,7 +451,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
     def initial_creator(self) -> str | None:
         """Get or set the initial creator of a document <meta:initial-creator>.
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
         """
         return self.get_initial_creator()
 
@@ -454,7 +464,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
         """Get or set the name of the last person who printed a document.
         <meta:printed-by>
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
         """
         element = self.get_element("//meta:printed-by")
         if element is None:
@@ -475,7 +485,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         (Also available as "self.keyword" and "self.keywords" property.)
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
         """
         element = self.get_element("//meta:keyword")
         if element is None:
@@ -503,7 +513,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
         """Get or set some keyword(s) keyword pertaining to a document
         <dc:keyword>.
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
         """
         return self.get_keywords()
 
@@ -518,7 +528,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         (Also available as "self.editing_duration" property.)
 
-        Returns: timedelta (or None if inexistant)
+        Returns: timedelta (or None if inexistent)
         """
         element = self.get_element("//meta:editing-duration")
         if element is None:
@@ -548,7 +558,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
         """Get or set the total time spent editing a document <meta:editing-
         duration>.
 
-        Returns: timedelta (or None if inexistant)
+        Returns: timedelta (or None if inexistent)
         """
         return self.get_editing_duration()
 
@@ -562,7 +572,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         (Also available as "self.editing_cycles" property.)
 
-        Returns: int (or None if inexistant)
+        Returns: int (or None if inexistent)
         """
         element = self.get_element("//meta:editing-cycles")
         if element is None:
@@ -597,7 +607,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
         When a document is created, this value is set to 1. Each time
         a document is saved, the editing-cycles number is incremented by 1.
 
-        Returns: int (or None if inexistant)
+        Returns: int (or None if inexistent)
         """
         return self.get_editing_cycles()
 
@@ -610,7 +620,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
         """Get or set the signature of the software that generated this
         document.
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
 
         Example::
 
@@ -637,7 +647,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         (Also available as "self.generator" property.)
 
-        Returns: str (or None if inexistant)
+        Returns: str (or None if inexistent)
 
         Example::
 
@@ -677,7 +687,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         (Also available as "self.statistic" property.)
 
-        Returns: dict (or None if inexistant)
+        Returns: dict (or None if inexistent)
 
         Example::
 
@@ -739,7 +749,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
         """Get or set the statistics about a document, "meta:document-
         statistic" tag.
 
-        Returns: dict (or None if inexistant)
+        Returns: dict (or None if inexistent)
 
         Example::
 
@@ -759,54 +769,53 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
     def statistic(self, statistic: dict[str, int]) -> None:
         return self.set_statistic(statistic)
 
-    def get_user_defined_metadata(self) -> dict[str, Any]:
+    def get_user_defined_metadata(
+        self,
+    ) -> dict[str, Decimal | datetime | dtdate | timedelta | bool | str]:
         """Get all additional user-defined metadata for a document.
 
         (Also available as "self.user_defined_metadata" property.)
 
         Return a dict of str/value mapping.
 
-        Value types can be: Decimal, date, time, boolean or str.
+        Value types can be: Decimal, datetime, date, timedelta, bool or str.
         """
-        result: dict[str, Any] = {}
-        for item in self.get_elements("//meta:user-defined"):
-            # Read the values
-            name = item.get_attribute_string("meta:name")
-            if name is None:
-                continue
-            value = self._get_meta_value(item)
-            result[name] = value
-        return result
-
-    def _user_defined_metadata_list(self) -> list[dict[str, Any]]:
-        user_defined: list[dict[str, Any]] = []
-        for item in self.get_elements("//meta:user-defined"):
-            # Read the values
-            name = item.get_attribute_string("meta:name")
-            if not name:
-                continue
-            value, value_type, _text = self._get_meta_value_full(item)
-            user_defined.append(
-                {"meta:name": name, "meta:value-type": value_type, "value": value}
+        return {
+            data.name: data.value
+            for data in cast(
+                list[MetaUserDefined], self.get_elements("//meta:user-defined")
             )
+        }
+
+    def _user_defined_metadata_list(
+        self,
+    ) -> list[dict[str, Decimal | datetime | dtdate | timedelta | bool | str]]:
+        user_defined = [
+            data.as_dict()
+            for data in cast(
+                list[MetaUserDefined], self.get_elements("//meta:user-defined")
+            )
+        ]
         return sorted(user_defined, key=itemgetter("meta:name"))
 
     def clear_user_defined_metadata(self) -> None:
         """Remove all user-defined metadata."""
         while True:
             element = self.get_element("//meta:user-defined")
-            if isinstance(element, Element):
+            if isinstance(element, MetaUserDefined):
                 element.delete()
                 continue
             break
 
     @property
-    def user_defined_metadata(self) -> dict[str, Any]:
+    def user_defined_metadata(
+        self,
+    ) -> dict[str, Decimal | datetime | dtdate | timedelta | bool | str]:
         """Get or set all additional user-defined metadata for a document.
 
         Return a dict of str/value mapping.
 
-        Value types can be: Decimal, date, time, boolean or str.
+        Value types can be: Decimal, datetime, date, timedelta, bool or str.
         """
         return self.get_user_defined_metadata()
 
@@ -816,9 +825,17 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
         for key, val in metadata.items():
             self.set_user_defined_metadata(name=key, value=val)
 
+    def _user_defined_metadata_by_name(self, name: str) -> MetaUserDefined | None:
+        for item in cast(
+            list[MetaUserDefined], self.get_elements("//meta:user-defined")
+        ):
+            if item.name == name:
+                return item
+        return None
+
     def get_user_defined_metadata_of_name(self, keyname: str) -> dict[str, Any] | None:
         """Return the content of the user defined metadata of that name. Return
-        None if no name matchs or a dic of fields.
+        None if no name matches or a dic of fields.
 
         Args:
 
@@ -826,24 +843,24 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
         Returns: a dict with keys "name", "value", "value_type", "text".
         """
-        result = {}
-        found = False
-        for item in self.get_elements("//meta:user-defined"):
-            # Read the values
-            name = item.get_attribute("meta:name")
-            if name == keyname:
-                found = True
-                break
-        if not found:
+        item = self._user_defined_metadata_by_name(keyname)
+        if item is None:
             return None
-        result["name"] = name
-        value, value_type, text = self._get_meta_value(item, full=True)
-        result["value"] = value
-        result["value_type"] = value_type
-        result["text"] = text
-        return result
+        return item.as_dict_full()
 
-    def set_user_defined_metadata(self, name: str, value: Any) -> None:
+    def set_user_defined_metadata(
+        self,
+        name: str,
+        value: bool
+        | int
+        | float
+        | Decimal
+        | datetime
+        | dtdate
+        | str
+        | timedelta
+        | None,
+    ) -> None:
         """Set a user defined metadata of that name and value.
 
         If value is None, any existing metadata of that name is deleted.
@@ -852,84 +869,33 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
 
             name -- string, name (meta:name content)
 
-            value -- Decimal, date, time, boolean, str, None for deletion.
+            value -- bool, int, float, Decimal, datetime, dtdate, str, timedelta or None for deletion.
         """
         if value is None:
-            return self.delete_user_defined_metadata_of_name(name)
-        if isinstance(value, bool):
-            value_type = "boolean"
-            value = "true" if value else "false"
-        elif isinstance(value, (int, float, Decimal)):
-            value_type = "float"
-            value = str(value)
-        elif isinstance(value, datetime):
-            value_type = "date"
-            value = str(DateTime.encode(value))
-        elif isinstance(value, dtdate):
-            value_type = "date"
-            value = str(Date.encode(value))
-        elif isinstance(value, str):
-            value_type = "string"
-        elif isinstance(value, timedelta):
-            value_type = "time"
-            value = str(Duration.encode(value))
-        else:
-            raise TypeError(f'unexpected type "{type(value)}" for value')
+            self.delete_user_defined_metadata_of_name(name)
+            return
+        value_type = MetaUserDefined._value_to_value_type(value)
         # Already the same element ?
-        for metadata in self.get_elements("//meta:user-defined"):
-            if metadata.get_attribute("meta:name") == name:
-                break
-        else:
-            metadata = Element.from_tag("meta:user-defined")
-            metadata.set_attribute("meta:name", name)
+        metadata = self._user_defined_metadata_by_name(name)
+        if metadata is None:
+            metadata = MetaUserDefined(name=name, value_type=value_type, value=value)
             self.body.append(metadata)
-        metadata.set_attribute("meta:value-type", value_type)
-        metadata.text = value
+        else:
+            metadata.value_type = value_type
+            metadata.value = value
 
     def delete_user_defined_metadata_of_name(self, name: str) -> None:
         """Delete the user-defined metadata of that name.
 
         Args:
 
-            name -- string, name (meta:name content)
+            name -- str, name of user-defined metadata (meta:name content)
         """
-        for metadata in self.get_elements("//meta:user-defined"):
-            if metadata.get_attribute("meta:name") == name:
-                metadata.delete()
-
-    def _get_meta_value(
-        self, element: Element, full: bool = False
-    ) -> Any | tuple[Any, str, str]:
-        """get_value() deicated to the meta data part, for one meta element."""
-        if full:
-            return self._get_meta_value_full(element)
-        else:
-            return self._get_meta_value_full(element)[0]
-
-    @staticmethod
-    def _get_meta_value_full(element: Element) -> tuple[Any, str, str]:
-        """get_value deicated to the meta data part, for one meta element."""
-        # name = element.get_attribute('meta:name')
-        value_type = element.get_attribute_string("meta:value-type")
-        if value_type is None:
-            value_type = "string"
-        text = element.text
-        # Interpretation
-        if value_type == "boolean":
-            return (Boolean.decode(text), value_type, text)
-        if value_type in ("float", "percentage", "currency"):
-            return (Decimal(text), value_type, text)
-        if value_type == "date":
-            if "T" in text:
-                return (DateTime.decode(text), value_type, text)
-            else:
-                return (Date.decode(text), value_type, text)
-        if value_type == "string":
-            return (text, value_type, text)
-        if value_type == "time":
-            return (Duration.decode(text), value_type, text)
-        # should never happen
-        raise TypeError(f"Unknown value type: '{value_type!r}'")  # pragma: nocover
+        while True:
+            metadata = self._user_defined_metadata_by_name(name)
+            if not metadata:
+                return
+            metadata.delete()
 
     def as_dict(self, full: bool = False) -> dict[str, Any]:
         """Return the metadata of the document as a Python dict.
@@ -944,7 +910,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
         def _stats() -> dict[str, int]:
             doc_stats = self.statistic
             if doc_stats is None:
-                msg = "Document statitics not found"
+                msg = "Document statistics not found"
                 raise LookupError(msg)
             return {
                 key: doc_stats.get(key, 0)
@@ -1048,8 +1014,8 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
             indent=4,
         )
 
-    def as_text(self) -> str:
-        """Return meta informations as text, with some formatting for
+    def as_text(self, no_user_defined_msg: str = "") -> str:
+        """Return meta information as text, with some formatting for
         printing.
         """
         data = self._as_json_dict(full=False)
@@ -1078,8 +1044,12 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
         for name, value in statistic.items():
             result.append(f"  - {name[5:].replace('-', ' ').capitalize()}: {value}")
 
-        result.append("User defined metadata:")
         user_metadata = data.get("meta:user-defined", [])
+        if user_metadata:
+            msg = ""
+        else:
+            msg = f" {no_user_defined_msg}"
+        result.append(f"User defined metadata:{msg}")
         for item in user_metadata:
             result.append(f"  - {item['meta:name']}: {item['value']}")
 
@@ -1265,7 +1235,7 @@ class Meta(XmlPart, DcCreatorMixin, DcDateMixin):
                     for v in current_dict.values()
                     if v["value"] is not None
                 }
-                self.user_defined_metadata = new_ud
+                self.user_defined_metadata = new_ud  # type: ignore[assignment]
 
     def strip(
         self,
