@@ -27,8 +27,8 @@ from datetime import datetime
 from functools import wraps
 from typing import TYPE_CHECKING, Any
 
-from .annotation import Annotation, AnnotationEnd
-from .bookmark import Bookmark, BookmarkEnd, BookmarkStart
+from .annotation import Annotation, AnnotationEnd, AnnotationMixin
+from .bookmark import Bookmark, BookmarkEnd, BookmarkMixin, BookmarkStart
 from .element import (
     FIRST_CHILD,
     NEXT_SIBLING,
@@ -39,7 +39,13 @@ from .element_strip import strip_elements, strip_tags
 from .line_break import LineBreak
 from .link import Link
 from .note import Note
-from .reference import Reference, ReferenceMark, ReferenceMarkEnd, ReferenceMarkStart
+from .reference import (
+    Reference,
+    ReferenceMark,
+    ReferenceMarkEnd,
+    ReferenceMarkStart,
+    ReferenceMixin,
+)
 from .spacer import Spacer
 from .tab import Tab
 
@@ -189,7 +195,7 @@ def _by_regex_offset(method: Callable) -> Callable:
     return wrapper
 
 
-class ParaMixin(Element):
+class ParaMixin(ReferenceMixin, BookmarkMixin, AnnotationMixin):
     """Mixin for Paragraph methods."""
 
     def _expand_spaces(self, added_string: str) -> list[Element | str]:
@@ -383,9 +389,9 @@ class ParaMixin(Element):
         date: datetime | None = None,
     ) -> Annotation:
         """Insert an annotation, at the position defined by the regex (before,
-        after, content) or by positionnal argument (position). If content is
+        after, content) or by positional argument (position). If content is
         provided, the annotation covers the full content regex. Else, the
-        annotation is positionned either 'before' or 'after' provided regex.
+        annotation is positioned either 'before' or 'after' provided regex.
 
         If content is an odf element (ie: paragraph, span, ...), the full inner
         content is covered by the annotation (of the position just after if
@@ -539,10 +545,10 @@ class ParaMixin(Element):
         content: str | Element | None = None,
     ) -> Element:
         """Insert a reference mark, at the position defined by the regex
-        (before, after, content) or by positionnal argument (position). If
+        (before, after, content) or by positional argument (position). If
         content is provided, the annotation covers the full range content regex
         (instances of ReferenceMarkStart and ReferenceMarkEnd are created).
-        Else, an instance of ReferenceMark is positionned either 'before' or
+        Else, an instance of ReferenceMark is positioned either 'before' or
         'after' provided regex.
 
         If content is an ODF Element (ie: Paragraph, Span, ...), the full inner
@@ -790,7 +796,7 @@ class ParaMixin(Element):
         ref_format is the argument for format reference (default is 'page').
 
         The reference is inserted the position defined by the regex (before /
-        after), or by positionnal argument (position). If 'display' is provided,
+        after), or by positional argument (position). If 'display' is provided,
         it will be used as the text value for the reference.
 
         If after is an ODF Element, the reference is inserted as first child of
@@ -817,7 +823,10 @@ class ParaMixin(Element):
         if display is None and ref_format == "text":
             # get reference content
             body: Body | Element = self.document_body or self.root
-            mark = body.get_reference_mark(name=name)
+            if hasattr(body, "get_reference_mark"):
+                mark = body.get_reference_mark(name=name)
+            else:
+                mark = None
             if isinstance(mark, ReferenceMarkStart):
                 display = mark.referenced_text()
         if not display:
