@@ -27,7 +27,7 @@ from __future__ import annotations
 
 import contextlib
 from collections.abc import Iterable, Iterator
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, cast
 
 from .cell import Cell
 from .element import (
@@ -45,7 +45,7 @@ if TYPE_CHECKING:
     from .style import Style
 
 
-_xpath_cell = xpath_compile("(table:table-cell|table:covered-table-cell)")
+_XPATH_CELL = xpath_compile("(table:table-cell|table:covered-table-cell)")
 
 
 class Row(Element):
@@ -98,12 +98,12 @@ class Row(Element):
         if isinstance(xpath_query, str):
             elements = xpath_return_elements(
                 xpath_compile(xpath_query),
-                self._Element__element,  # type: ignore[attr-defined]
+                self._xml_element,
             )
         else:
             elements = xpath_return_elements(
                 xpath_query,
-                self._Element__element,  # type: ignore[attr-defined]
+                self._xml_element,
             )
         cache = (self._table_cache, self._row_cache)
         return [Element.from_tag_for_clone(e, cache) for e in elements]
@@ -116,12 +116,12 @@ class Row(Element):
 
     def clear(self) -> None:
         """Remove text, children and attributes from the Row."""
-        self._Element__element.clear()  # type: ignore[attr-defined]
+        self._xml_element.clear()
         self._table_cache = TableCache()
         self._row_cache = RowCache()
 
     def _get_cells(self) -> list[Cell]:
-        return self.get_elements(_xpath_cell)  # type: ignore[return-value]
+        return cast(list[Cell], self.get_elements(_XPATH_CELL))
 
     def _translate_row_coordinates(
         self,
@@ -140,7 +140,7 @@ class Row(Element):
 
     def _compute_row_cache(self) -> None:
         idx_repeated_seq = self.elements_repeated_sequence(
-            _xpath_cell, "table:number-columns-repeated"
+            _XPATH_CELL, "table:number-columns-repeated"
         )
         self._row_cache.make_cell_map(idx_repeated_seq)
 
@@ -155,7 +155,7 @@ class Row(Element):
         return cloned_row
 
     def _set_repeated(self, repeated: int | None) -> None:
-        """Method Internal only. Set the numnber of times the row is repeated,
+        """Method Internal only. Set the number of times the row is repeated,
         or None to delete it. Without changing cache.
 
         Args:
@@ -679,7 +679,7 @@ class Row(Element):
         currency: str | None = None,
     ) -> None:
         """Shortcut to set the value of cells in the row, from the 'start'
-        column vith values. This method does not clear the row, use row.clear()
+        column with values. This method does not clear the row, use row.clear()
         before to start with an empty row.
 
         Args:
@@ -739,7 +739,7 @@ class Row(Element):
         Returns: int
         """
         idx_repeated_seq = self.elements_repeated_sequence(
-            _xpath_cell, "table:number-columns-repeated"
+            _XPATH_CELL, "table:number-columns-repeated"
         )
         repeated = [item[1] for item in idx_repeated_seq]
         if repeated:
@@ -753,7 +753,7 @@ class Row(Element):
         Returns: int
         """
         idx_repeated_seq = self.elements_repeated_sequence(
-            _xpath_cell, "table:number-columns-repeated"
+            _XPATH_CELL, "table:number-columns-repeated"
         )
         repeated = [item[1] for item in idx_repeated_seq]
         if repeated:
