@@ -27,12 +27,12 @@ from __future__ import annotations
 
 import csv
 import os
-from collections.abc import Iterator
+from collections.abc import Iterable, Iterator
 from io import StringIO
 from itertools import zip_longest
 from pathlib import Path
 from textwrap import wrap
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Union, cast
 from warnings import warn
 
 from lxml.etree import XPath
@@ -43,13 +43,17 @@ from .column import Column
 from .datatype import Boolean, Date, DateTime, Duration
 from .element import (
     Element,
+    EText,
     register_element_class,
     xpath_compile,
     xpath_return_elements,
 )
+from .form import FormMixin
 from .frame import Frame
 from .mixin_md import MDTable
+from .mixin_named_range import TableNamedExpressions
 from .named_range import NamedRange, table_name_check
+from .office_forms import OfficeFormsMixin
 from .row import Row
 from .row_group import RowGroup
 from .table_cache import _XP_COLUMN_IDX, _XP_ROW_IDX, TableCache
@@ -62,7 +66,6 @@ from .utils import (
 )
 
 if TYPE_CHECKING:
-    from .element import EText
     from .style import Style
 
 _XP_ROW = xpath_compile(
@@ -79,12 +82,16 @@ _XP_ROW_GROUP = xpath_compile(
 )
 
 
-def _get_python_value(data: Any, encoding: str) -> Any:
+def _get_python_value(data: str | bytes | int | float | bool, encoding: str) -> Any:
     """Try and guess the most appropriate Python type to load the data, with
     regard to ODF types.
+
+    The data should come from a CSV analyzer.
     """
     if isinstance(data, bytes):
         data = data.decode(encoding)
+    if isinstance(data, (float, int, bool)):
+        return data
     # An int ?
     try:
         return int(data)
@@ -117,12 +124,11 @@ def _get_python_value(data: Any, encoding: str) -> Any:
         return Boolean.decode(data.lower())
     except ValueError:
         pass
-    # TODO Try some other types ?
-    # So a text
+    # So a string
     return data
 
 
-class Table(MDTable, Element):
+class Table(MDTable, FormMixin, OfficeFormsMixin, Element):
     """A table, in a spreadsheet or other document, "table:table"."""
 
     _tag = "table:table"
@@ -162,7 +168,7 @@ class Table(MDTable, Element):
         handling repetitions and the same number of cells for each row.
 
         If you use both the table API and the XML API, you are on your own for
-        ensuiring model integrity.
+        ensuring model integrity.
 
         Args:
 
@@ -188,7 +194,11 @@ class Table(MDTable, Element):
             self.name = name or ""
             if protected:
                 self.protected = protected
-                self.set_protection_key = protection_key
+                if protection_key is None:
+                    raise ValueError(
+                        "a protection_key must be provided for protected tables"
+                    )
+                self.protection_key = protection_key
             if not printable:
                 self.printable = printable
             if print_ranges:
@@ -236,27 +246,23 @@ class Table(MDTable, Element):
         if isinstance(xpath_query, str):
             elements = xpath_return_elements(
                 xpath_compile(xpath_query),
-                self._Element__element,  # type: ignore[attr-defined]
+                self._xml_element,
             )
         else:
             elements = xpath_return_elements(
                 xpath_query,
-                self._Element__element,  # type: ignore[attr-defined]
+                self._xml_element,
             )
         cache = (self._table_cache, None)
         return [Element.from_tag_for_clone(e, cache) for e in elements]
 
-    def _copy_cache(self, cache: tuple | None) -> None:
-        """Copy cache when cloning."""
-        self._table_cache = cache[0]  # type:ignore[index]
-
     def clear(self) -> None:
         """Remove text, children and attributes from the Row."""
-        self._Element__element.clear()  # type:ignore[attr-defined]
+        self._xml_element.clear()
         self._table_cache = TableCache()
 
     def _translate_y_from_any(self, y: str | int) -> int:
-        # "3" (couting from 1) -> 2 (couting from 0)
+        # "3" (counting from 1) -> 2 (counting from 0)
         return translate_from_any(y, self.height, 1)
 
     def _translate_table_coordinates_list(
@@ -297,26 +303,13 @@ class Table(MDTable, Element):
         self,
         coord_str: str,
     ) -> tuple[int | None, ...]:
-        height = self.height
-        width = self.width
         coord = convert_coordinates(coord_str)
+        # resulting coord has never <0 value
         if len(coord) == 2:
             x, y = coord
-            if x and x < 0:
-                x = increment(x, width)
-            if y and y < 0:
-                y = increment(y, height)
             # extent to an area :
             return (x, y, x, y)
         x, y, z, t = coord
-        if x and x < 0:
-            x = increment(x, width)
-        if y and y < 0:
-            y = increment(y, height)
-        if z and z < 0:
-            z = increment(z, width)
-        if t and t < 0:
-            t = increment(t, height)
         return (x, y, z, t)
 
     def _translate_table_coordinates(
@@ -331,26 +324,13 @@ class Table(MDTable, Element):
         self,
         coord_str: str,
     ) -> tuple[int | None, ...]:
-        width = self.width
-        height = self.height
         coord = convert_coordinates(coord_str)
+        # resulting coord has never <0 value
         if len(coord) == 2:
             x, y = coord
-            if x and x < 0:
-                x = increment(x, width)
-            if y and y < 0:
-                y = increment(y, height)
             # extent to an area :
             return (x, y, x, y)
         x, y, z, t = coord
-        if x and x < 0:
-            x = increment(x, width)
-        if y and y < 0:
-            y = increment(y, height)
-        if z and z < 0:
-            z = increment(z, width)
-        if t and t < 0:
-            t = increment(t, height)
         return (x, y, z, t)
 
     def _translate_column_coordinates_list(
@@ -659,15 +639,11 @@ class Table(MDTable, Element):
 
     @property
     def printable(self) -> bool:
-        printable = self.get_attribute("table:print")
-        # Default value
-        if printable is None:
-            return True
-        return bool(printable)
+        return self._get_attribute_bool_default("table:print", True)
 
     @printable.setter
     def printable(self, printable: bool) -> None:
-        self.set_attribute("table:print", printable)
+        self._set_attribute_bool_default("table:print", printable, True)
 
     @property
     def print_ranges(self) -> list[str]:
@@ -781,7 +757,7 @@ class Table(MDTable, Element):
 
         Filter by coordinates will parse the area defined by the coordinates.
 
-        cell_type, complete, grt_type : see get_values()
+        cell_type, complete, get_type : see get_values()
 
 
 
@@ -843,7 +819,7 @@ class Table(MDTable, Element):
         before setting values, use table.clear().
 
         A list of lists is expected, with as many lists as rows, and as many
-        items in each sublist as cells to be setted. None values in the list
+        items in each sublist as cells to be set. None values in the list
         will create empty cells with no cell type (but eventually a style).
 
         Args:
@@ -913,16 +889,14 @@ class Table(MDTable, Element):
         self._table_cache.clear_row_indexes()
         # Step 3: trim columns to match max_width
         columns = self._get_columns()
-        repeated_cols: list[EText] = self.xpath(  # type: ignore[assignment]
-            "table:table-column/@table:number-columns-repeated"
+        repeated_cols: list[EText] = cast(
+            list[EText], self.xpath("table:table-column/@table:number-columns-repeated")
         )
-        if not isinstance(repeated_cols, list):
-            raise TypeError
         unrepeated = len(columns) - len(repeated_cols)
         column_width = sum(int(r) for r in repeated_cols) + unrepeated
         diff = column_width - max_width
         if diff > 0:
-            for column in reversed(columns):
+            for column in reversed(columns):  # pragma: nocover
                 repeated = column.repeated or 1
                 repeated = repeated - diff
                 if repeated > 0:
@@ -956,7 +930,7 @@ class Table(MDTable, Element):
             else:
                 break
         if count > 0:
-            for row in reversed(self._get_rows()):
+            for row in reversed(self._get_rows()):  # pragma: nocover
                 row.parent.delete(row)  # type: ignore[union-attr]
                 count -= 1
                 if count <= 0:
@@ -982,16 +956,15 @@ class Table(MDTable, Element):
     def _optimize_width_adapt_columns(self, width: int) -> None:
         # trim columns to match minimal_width
         columns = self._get_columns()
-        repeated_cols: list[EText] = self.xpath(  # type: ignore[assignment]
-            "table:table-column/@table:number-columns-repeated"
+        repeated_cols: list[EText] = cast(
+            list[EText],
+            self.xpath("table:table-column/@table:number-columns-repeated"),
         )
-        if not isinstance(repeated_cols, list):
-            raise TypeError
         unrepeated = len(columns) - len(repeated_cols)
         column_width = sum(int(r) for r in repeated_cols) + unrepeated
         diff = column_width - width
         if diff > 0:
-            for column in reversed(columns):
+            for column in reversed(columns):  # pragma: nocover
                 repeated = column.repeated or 1
                 repeated = repeated - diff
                 if repeated > 0:
@@ -1025,10 +998,7 @@ class Table(MDTable, Element):
                 data.append(row.cells)
             transposed_data = zip_longest(*data)
             self.clear()
-            # new_rows = []
             for row_cells in transposed_data:
-                if not isiterable(row_cells):
-                    row_cells = (row_cells,)
                 row = Row()
                 row.extend_cells(row_cells)
                 self.append_row(row, clone=False)
@@ -1061,13 +1031,10 @@ class Table(MDTable, Element):
                 nones = [[None] * w for i in range(h)]
                 self.set_values(nones, coord=(x, y, z, t))
             # put transposed
-            filtered_data: list[tuple[Cell]] = []
-            for row_cells in transposed_data:
-                if isinstance(row_cells, (list, tuple)):
-                    filtered_data.append(row_cells)
-                else:
-                    filtered_data.append((row_cells,))
-            self.set_cells(filtered_data, (x, y, x + h - 1, y + w - 1))
+            self.set_cells(
+                cast(Iterable[tuple[Cell]], transposed_data),
+                (x, y, x + h - 1, y + w - 1),
+            )
             self._compute_table_cache()
 
     def is_empty(self, aggressive: bool = False) -> bool:
@@ -1092,10 +1059,10 @@ class Table(MDTable, Element):
 
         Returns: list of RowGroup
         """
-        return self.get_elements(_XP_ROW_GROUP)  # type: ignore[return-value]
+        return cast(list[RowGroup], self.get_elements(_XP_ROW_GROUP))
 
     def _get_rows(self) -> list[Row]:
-        return self.get_elements(_XP_ROW)  # type: ignore[return-value]
+        return cast(list[Row], self.get_elements(_XP_ROW))
 
     def iter_rows(
         self,
@@ -1217,7 +1184,7 @@ class Table(MDTable, Element):
 
         Position start at 0. So cell A4 is on row 3.
 
-        A copy is returned, use set_cell() to push it back.
+        A copy is returned, use set_row() to push it back.
 
         Args:
 
@@ -1234,7 +1201,7 @@ class Table(MDTable, Element):
         return row
 
     def set_row(self, y: int | str, row: Row | None = None, clone: bool = True) -> Row:
-        """Replace the row at the given position with the new one. Repetions of
+        """Replace the row at the given position with the new one. Repetitions of
         the old row will be adjusted.
 
         If row is None, a new empty row is created.
@@ -1601,7 +1568,7 @@ class Table(MDTable, Element):
     ) -> Cell:
         """Get the cell at the given coordinates.
 
-        They are either a 2-uplet of (x, y) starting from 0, or a
+        They are either a 2-tuple of (x, y) starting from 0, or a
         human-readable position like "C4".
 
         A copy is returned, use ``set_cell`` to push it back.
@@ -1647,7 +1614,7 @@ class Table(MDTable, Element):
 
         If get_type is True, returns the tuples (value, ODF type)
 
-        coord is either a 2-uplet of (x, y) starting from 0, or a
+        coord is either a 2-tuple of (x, y) starting from 0, or a
         human-readable position like "C4". If an Area is given, the upper
         left position is used as coord.
 
@@ -1687,7 +1654,7 @@ class Table(MDTable, Element):
     ) -> Cell:
         """Replace a cell of the table at the given coordinates.
 
-        They are either a 2-uplet of (x, y) starting from 0, or a
+        They are either a 2-tuple of (x, y) starting from 0, or a
         human-readable position like "C4".
 
         Args:
@@ -1732,7 +1699,7 @@ class Table(MDTable, Element):
 
     def set_cells(
         self,
-        cells: list[list[Cell]] | list[tuple[Cell]],
+        cells: Iterable[list[Cell]] | Iterable[tuple[Cell]],
         coord: tuple | list | str | None = None,
         clone: bool = True,
     ) -> None:
@@ -1747,7 +1714,7 @@ class Table(MDTable, Element):
         before setting cells, use table.clear().
 
         A list of lists is expected, with as many lists as rows to be set, and
-        as many cell in each sublist as cells to be setted in the row.
+        as many cell in each sublist as cells to be set in the row.
 
         Args:
 
@@ -1788,7 +1755,7 @@ class Table(MDTable, Element):
     ) -> None:
         """Set the Python value of the cell at the given coordinates.
 
-        They are either a 2-uplet of (x, y) starting from 0, or a
+        They are either a 2-tuple of (x, y) starting from 0, or a
         human-readable position like "C4".
 
         Args:
@@ -1821,7 +1788,7 @@ class Table(MDTable, Element):
         Do all the magic to display an image in the cell at the given
         coordinates.
 
-        They are either a 2-uplet of (x, y) starting from 0, or a
+        They are either a 2-tuple of (x, y) starting from 0, or a
         human-readable position like "C4".
 
         The frame element must contain the expected image position and
@@ -1890,7 +1857,7 @@ class Table(MDTable, Element):
         """Insert the given cell at the given coordinates. If no cell is given,
         an empty one is created.
 
-        Coordinates are either a 2-uplet of (x, y) starting from 0, or a
+        Coordinates are either a 2-tuple of (x, y) starting from 0, or a
         human-readable position like "C4".
 
         Cells on the right are shifted. Other rows remain untouched.
@@ -1961,7 +1928,7 @@ class Table(MDTable, Element):
         """Delete the cell at the given coordinates, so that next cells are
         shifted to the left.
 
-        Coordinates are either a 2-uplet of (x, y) starting from 0, or a
+        Coordinates are either a 2-tuple of (x, y) starting from 0, or a
         human-readable position like "C4".
 
         Use set_value() for erasing value.
@@ -1988,7 +1955,7 @@ class Table(MDTable, Element):
     # Columns
 
     def _get_columns(self) -> list[Column]:
-        return self.get_elements(_XP_COLUMN)  # type: ignore[return-value]
+        return cast(list[Column], self.get_elements(_XP_COLUMN))
 
     def iter_columns(
         self,
@@ -2455,10 +2422,10 @@ class Table(MDTable, Element):
     # Named Range
     def _local_named_ranges(self) -> list[NamedRange]:
         """(internal) Return the list of local Name Ranges."""
-        named_ranges = self.get_elements(
-            "descendant::table:named-expressions/table:named-range"
+        return cast(
+            list[NamedRange],
+            self.get_elements("descendant::table:named-expressions/table:named-range"),
         )
-        return named_ranges  # type: ignore[return-value]
 
     def _local_named_range(self, name: str) -> NamedRange | None:
         """(internal) Return the local Name Range of the specified name."""
@@ -2466,23 +2433,26 @@ class Table(MDTable, Element):
             f'descendant::table:named-expressions/table:named-range[@table:name="{name}"][1]'
         )
         if named_range:
-            return named_range[0]  # type: ignore[return-value]
+            return cast(NamedRange, named_range[0])
         else:
             return None
 
     def _local_append_named_range(self, named_range: NamedRange) -> None:
         """(internal) Append the named range to the current table."""
-        named_expressions = self.get_element("table:named-expressions")
+        named_expressions = cast(
+            Union[None, TableNamedExpressions],
+            self.get_element(TableNamedExpressions._tag),
+        )
         if not named_expressions:
-            named_expressions = Element.from_tag("table:named-expressions")
-            self._Element__append(named_expressions)  # type: ignore[attr-defined]
+            named_expressions = TableNamedExpressions()
+            self._xml_append(named_expressions)
         # exists ?
         current = named_expressions.get_element(
             f'table:named-range[@table:name="{named_range.name}"][1]'
         )
         if current:
             named_expressions.delete(current)
-        named_expressions._Element__append(named_range)  # type: ignore[attr-defined]
+        named_expressions._xml_append(named_range)
 
     def _local_set_named_range(
         self, name: str, crange: str | tuple | list, usage: str | None = None
@@ -2499,12 +2469,13 @@ class Table(MDTable, Element):
         if not named_range:
             return
         named_range.delete()
-        named_expressions = self.get_element("table:named-expressions")
+        named_expressions = cast(
+            Union[None, TableNamedExpressions],
+            self.get_element(TableNamedExpressions._tag),
+        )
         if not named_expressions:
             return
-        element = named_expressions._Element__element  # type: ignore[attr-defined]
-        children = list(element.iterchildren())
-        if not children:
+        if named_expressions.is_empty():
             self.delete(named_expressions)
 
     def get_named_ranges(
@@ -2522,7 +2493,7 @@ class Table(MDTable, Element):
 
             table_names -- str or list of str, names of tables
 
-            global_scope -- bool, serch in entire document or in the current table.
+            global_scope -- bool, search in entire document or in the current table.
 
         Returns : list of NamedRange
         """
@@ -2558,7 +2529,7 @@ class Table(MDTable, Element):
 
             name -- str, name of the named range object
 
-            global_scope -- bool, serch in entire document or in the current table.
+            global_scope -- bool, search in entire document or in the current table.
 
         Returns : NamedRange or None
         """
@@ -2589,7 +2560,7 @@ class Table(MDTable, Element):
 
             named_range --  NamedRange
 
-            global_scope -- bool, serch in entire document or in the current table.
+            global_scope -- bool, search in entire document or in the current table.
         """
         if global_scope:
             body = self.document_body
@@ -2631,7 +2602,7 @@ class Table(MDTable, Element):
 
             usage -- None or 'print-range', 'filter', 'repeat-column', 'repeat-row'
 
-            global_scope -- bool, serch in entire document or in the current table.
+            global_scope -- bool, search in entire document or in the current table.
         """
         name = name.strip()
         if not name:
@@ -2668,7 +2639,7 @@ class Table(MDTable, Element):
 
             name -- str
 
-            global_scope -- bool, serch in entire document or in the current table.
+            global_scope -- bool, search in entire document or in the current table.
         """
         name = name.strip()
         if not name:
@@ -2702,7 +2673,7 @@ class Table(MDTable, Element):
         If merge is True, replace text of the cell by the concatenation of
         existing text in covered cells.
         Beware : if merge is True, old text is changed, if merge is False
-        (the default), old text in coverd cells is still present but not
+        (the default), old text in covered cells is still present but not
         displayed by most GUI.
 
         If the area defines only one cell, the set span will do nothing.
@@ -2800,7 +2771,7 @@ class Table(MDTable, Element):
         return True
 
     def del_span(self, area: str | tuple | list) -> bool:
-        """Delete a Cell Span. 'area' is the cell coordiante of the upper left
+        """Delete a Cell Span. 'area' is the cell coordinate of the upper left
         cell of the spanned area.
 
         Area can be either one cell (like 'A1') or an area ('A1:B2'). It can
