@@ -27,7 +27,7 @@
 from __future__ import annotations
 
 from datetime import datetime
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Union, cast
 
 from .element import FIRST_CHILD, LAST_CHILD, Element, register_element_class
 from .elements_between import elements_between
@@ -35,16 +35,43 @@ from .mixin_dc_creator import DcCreatorMixin
 from .mixin_dc_date import DcDateMixin
 from .mixin_md import MDZap
 from .paragraph import Paragraph
+from .section import SectionMixin
 
 if TYPE_CHECKING:
-    from .body import Body
+    from .body import Body, Text
+
+
+class TrackedChangesMixin(Element):
+    """Mixin class for classes containing TrackedChanges.
+
+    Used by the following classes:  "office:text", "style:footer",
+    "style:footer-first", "style:footer-left", "style:header",
+    "style:header-first" and "style:header-left".
+    """
+
+    def get_tracked_changes(self) -> TrackedChanges | None:
+        """Return the tracked-changes part in the text body.
+
+        Returns: TrackedChanges or None
+        """
+        return cast(
+            Union[None, TrackedChanges], self.get_element("//text:tracked-changes")
+        )
+
+    @property
+    def tracked_changes(self) -> TrackedChanges | None:
+        """Return the tracked-changes part in the text body.
+
+        Returns: Element or None
+        """
+        return self.get_tracked_changes()
 
 
 class ChangeInfo(Element, DcCreatorMixin, DcDateMixin):
-    """Representation of informations of a change, "office:change-info".
+    """Representation of information of a change, "office:change-info".
 
     The "office:change-info" element represents who made a change and when.
-    It may also contain a comment (one or more Paragrah "text:p" elements)
+    It may also contain a comment (one or more Paragraph "text:p" elements)
     on the change.
 
     The comments available in the ChangeInfo are available through:
@@ -62,7 +89,7 @@ class ChangeInfo(Element, DcCreatorMixin, DcDateMixin):
         date: datetime | None = None,
         **kwargs: Any,
     ) -> None:
-        """Create informations of a change "office:change-info".
+        """Create information of a change "office:change-info".
 
         Args:
 
@@ -111,7 +138,7 @@ class ChangeInfo(Element, DcCreatorMixin, DcDateMixin):
 
 
 class TextInsertion(Element):
-    """Informations on a text insertion, "text:insertion".
+    """Information on a text insertion, "text:insertion".
 
     The TextInsertion "text:insertion" element contains the information that
     identifies the person responsible for a change and the date of that change.
@@ -170,12 +197,14 @@ class TextInsertion(Element):
             as_text=as_text, no_header=no_header, clean=clean
         )
 
-    def get_change_info(self) -> Element | None:
+    def get_change_info(self) -> ChangeInfo | None:
         """Get the ChangeInfo child of the element.
 
-        Returns: ChangeInfo element.
+        Returns: ChangeInfo element or None.
         """
-        return self.get_element("descendant::office:change-info")
+        return cast(
+            Union[None, ChangeInfo], self.get_element("descendant::office:change-info")
+        )
 
     def set_change_info(
         self,
@@ -188,7 +217,7 @@ class TextInsertion(Element):
         not provided, creator, date and comments will be used to build a
         suitable change info element. Default for creator is 'Unknown', default
         for date is current time and default for comments is no comment at all.
-        The new change info element will replace any existant ChangeInfo.
+        The new change info element will replace any existent ChangeInfo.
 
         Args:
 
@@ -204,7 +233,7 @@ class TextInsertion(Element):
             new_change_info = ChangeInfo(creator, date)
             if comments is not None:
                 if isinstance(comments, Element):
-                    # single pararagraph comment
+                    # single paragraph comment
                     comments_list = [comments]
                 else:
                     comments_list = comments
@@ -225,8 +254,8 @@ class TextInsertion(Element):
             self.insert(new_change_info, xmlposition=FIRST_CHILD)
 
 
-class TextDeletion(TextInsertion):
-    """Informations on a text deletion, "text:deletion".
+class TextDeletion(SectionMixin, TextInsertion):
+    """Information on a text deletion, "text:deletion".
 
     The TextDeletion "text:deletion" contains information that identifies
     the person responsible for a deletion and the date of that deletion.
@@ -261,7 +290,7 @@ class TextDeletion(TextInsertion):
         as_text: bool = False,
         no_header: bool = False,
     ) -> str | list[Element] | None:
-        """Get the deleted informations stored in the TextDeletion.
+        """Get the deleted information stored in the TextDeletion.
         If as_text is True: returns the text content.
         If no_header is True: existing Heading are changed in Paragraph
 
@@ -276,7 +305,7 @@ class TextDeletion(TextInsertion):
         children = self.children
         inner = [elem for elem in children if elem.tag != "office:change-info"]
         if no_header:  # crude replace t:h by t:p
-            print("noheader")
+            print("noheaders")
             new_inner = []
             for element in inner:
                 if element.tag == "text:h":
@@ -295,8 +324,8 @@ class TextDeletion(TextInsertion):
         return inner
 
     def set_deleted(self, paragraph_or_list: Element | list[Element]) -> None:
-        """Set the deleted informations stored in the TextDeletion. An actual
-        content that was deleted is expected, embeded in a Paragraph element or
+        """Set the deleted information stored in the TextDeletion. An actual
+        content that was deleted is expected, embedded in a Paragraph element or
         Header.
 
         Args:
@@ -363,12 +392,14 @@ class TextChangedRegion(Element):
 
     _tag = "text:changed-region"
 
-    def get_change_info(self) -> Element | None:
+    def get_change_info(self) -> ChangeInfo | None:
         """Shortcut to get the ChangeInfo element of the change element child.
 
         Returns: ChangeInfo element.
         """
-        return self.get_element("descendant::office:change-info")
+        return cast(
+            Union[None, ChangeInfo], self.get_element("descendant::office:change-info")
+        )
 
     def set_change_info(
         self,
@@ -384,7 +415,7 @@ class TextChangedRegion(Element):
 
              change_info -- ChangeInfo element (or None)
 
-             cretor -- str (or None)
+             creator -- str (or None)
 
              date -- datetime (or None)
 
@@ -507,15 +538,15 @@ class TextChange(Element):
     def set_id(self, idx: str) -> None:
         self.set_attribute("text:change-id", idx)
 
-    def _get_tracked_changes(self) -> Element | None:
-        body = self.document_body
-        if not body:
-            raise ValueError
-        return body.get_tracked_changes()
+    def _get_tracked_changes(self) -> TrackedChanges | None:
+        body: Text | None = self.document_body  # type: ignore[assignment]
+        if body and body.tag == "office:text":
+            return body.get_tracked_changes()
+        raise ValueError
 
     def get_changed_region(
         self,
-        tracked_changes: Element | None = None,
+        tracked_changes: TrackedChanges | None = None,
     ) -> Element | None:
         if not tracked_changes:
             tracked_changes = self._get_tracked_changes()
@@ -524,7 +555,7 @@ class TextChange(Element):
 
     def get_change_info(
         self,
-        tracked_changes: Element | None = None,
+        tracked_changes: TrackedChanges | None = None,
     ) -> Element | None:
         changed_region = self.get_changed_region(tracked_changes=tracked_changes)
         if not changed_region:
@@ -533,7 +564,7 @@ class TextChange(Element):
 
     def get_change_element(
         self,
-        tracked_changes: Element | None = None,
+        tracked_changes: TrackedChanges | None = None,
     ) -> Element | None:
         changed_region = self.get_changed_region(tracked_changes=tracked_changes)
         if not changed_region:
@@ -542,12 +573,12 @@ class TextChange(Element):
 
     def get_deleted(
         self,
-        tracked_changes: Element | None = None,
+        tracked_changes: TrackedChanges | None = None,
         as_text: bool = False,
         no_header: bool = False,
         clean: bool = True,
     ) -> Element | None:
-        """Shortcut to get the deleted informations stored in the TextDeletion
+        """Shortcut to get the deleted information stored in the TextDeletion
         stored in the tracked changes.
 
         Returns: Paragraph (or None)."
