@@ -19,6 +19,7 @@
 # https://github.com/lpod/lpod-python
 # Authors: Romain Gauthier <romain@itaapy.com>
 #          Hervé Cauwelier <herve@itaapy.com>
+from __future__ import annotations
 
 import re
 from collections import namedtuple
@@ -39,6 +40,7 @@ from odfdo.element import (
     register_element_class,
     xpath_compile,
 )
+from odfdo.list import List
 from odfdo.named_range import NamedRange
 from odfdo.paragraph import Paragraph
 from odfdo.section import Section
@@ -73,6 +75,15 @@ def span_styles(samples) -> Iterable[Sample]:
     yield Sample(container=container, content=content, para=para, anno=anno, span=span)
 
 
+def test_element_init_completude_vs_registry():
+    import odfdo
+
+    all_imported = set(odfdo.__all__)
+    registry = odfdo.element._class_registry
+    for klass in registry.values():
+        assert klass.__name__ in all_imported
+
+
 def test_create_simple():
     data = "<p>Template Element</p>"
     element = Element.from_tag(data)
@@ -366,6 +377,42 @@ def test_del_attribute_namespace(sample):
     assert element.get_attribute("text:style-name") is None
 
 
+def test_set_attribute_str_default_1():
+    element = Element.from_tag("text:p")
+    element._set_attribute_str_default("test", "value", "default_value")
+    assert element.serialize() == '<text:p test="value"/>'
+
+
+def test_set_attribute_str_default_2():
+    element = Element.from_tag("text:p")
+    element._set_attribute_str_default("test", "default_value", "default_value")
+    assert element.serialize() == "<text:p/>"
+
+
+def test_get_attribute_str_default_1():
+    element = Element.from_tag('<text:p test="value"/>')
+    result = element._get_attribute_str_default("test", "default_value")
+    assert result == "value"
+
+
+def test_get_attribute_str_default_2():
+    element = Element.from_tag("<text:p/>")
+    result = element._get_attribute_str_default("test", "default_value")
+    assert result == "default_value"
+
+
+def test_set_attr_transparent_1():
+    element = Element.from_tag("<text:p/>")
+    element.set_attribute("dr3d:ambient-color", "blue")
+    assert element.serialize() == '<text:p dr3d:ambient-color="#0000FF"/>'
+
+
+def test_set_attr_transparent_2():
+    element = Element.from_tag("<text:p/>")
+    element.set_attribute("dr3d:ambient-color", "transparent")
+    assert element.serialize() == '<text:p dr3d:ambient-color="transparent"/>'
+
+
 def test_get_text(sample):
     element = sample.para
     text = element.text
@@ -824,6 +871,44 @@ def test_set_inner_text_none():
     assert element.serialize() == "<text:p>x y<text:span>new</text:span></text:p>"
 
 
+def test_get_inner_text_content():
+    element = Element.from_tag("<text:p>x y<text:span>content</text:span></text:p>")
+    result = element._get_inner_text("text:span")
+    assert result == "content"
+
+
+def test_get_inner_text_no_content():
+    element = Element.from_tag("<text:p>x y</text:p>")
+    result = element._get_inner_text("text:span")
+    assert result is None
+
+
+def test_svg_title_1():
+    element = Element.from_tag("<text:p>x</text:p>")
+    result = element.svg_title
+    assert result is None
+
+
+def test_svg_title_2():
+    element = Element.from_tag("<text:p>x</text:p>")
+    element.svg_title = "content"
+    result = element.svg_title
+    assert result == "content"
+
+
+def test_svg_description_1():
+    element = Element.from_tag("<text:p>x</text:p>")
+    result = element.svg_description
+    assert result is None
+
+
+def test_svg_description_2():
+    element = Element.from_tag("<text:p>x</text:p>")
+    element.svg_description = "content"
+    result = element.svg_description
+    assert result == "content"
+
+
 def test_sections(sample):
     content = sample.content
     result = content.body.sections
@@ -847,3 +932,48 @@ def test_append_named_range_in_class(tag):
     element.append_named_range(nr)
     result = element.get_named_range(name="nr_name")
     assert isinstance(result, NamedRange)
+
+
+def test_get_lists_1():
+    element = Element.from_tag("office:text")
+    result = element.get_lists()
+    assert result == []
+
+
+def test_get_lists_2():
+    element = Element.from_tag("office:text")
+    result = element.lists
+    assert result == []
+
+
+def test_get_lists_3():
+    element = Element.from_tag("office:text")
+    element.insert(List(["a", "b"]), position=0)
+    result = element.lists
+    assert len(result) == 1
+    assert isinstance(result[0], List)
+
+
+def test_get_lists_4():
+    element = Element.from_tag("office:text")
+    element.insert(List(["a", "b"]), position=0)
+    element.insert(List(["c"]), position=0)
+    result = element.lists
+    assert len(result) == 2
+    assert isinstance(result[0], List)
+
+
+def test_get_list_1():
+    element = Element.from_tag("office:text")
+    element.insert(List(["a", "b"]), position=0)
+    element.insert(List(["c"]), position=0)
+    result = element.get_list(content="c")
+    assert isinstance(result, List)
+
+
+def test_get_list_2():
+    element = Element.from_tag("office:text")
+    element.insert(List(["a", "b"]), position=0)
+    element.insert(List(["c"]), position=0)
+    result = element.get_list(content="z")
+    assert result is None
