@@ -29,6 +29,7 @@ from textwrap import dedent
 
 import pytest
 
+from odfdo import Meta
 from odfdo.body import Metadata
 from odfdo.const import ODF_META
 from odfdo.datatype import DateTime, Duration
@@ -40,7 +41,7 @@ from odfdo.meta_template import MetaTemplate
 
 
 @pytest.fixture
-def meta(samples) -> Iterable:
+def meta(samples) -> Iterable[Meta]:
     document = Document(samples("meta.odt"))
     yield document.get_part(ODF_META)
 
@@ -65,6 +66,15 @@ def test_title_property(meta):
     assert clone.title == title
 
 
+def test_title_property_empty(meta):
+    clone = meta.clone
+    orig = clone.get_element("//dc:title")
+    orig.delete()
+    title = "Nouvel intitulé"
+    clone.title = title
+    assert clone.title == title
+
+
 def test_get_description(meta):
     description = meta.get_description()
     expected = "Comments\nCommentaires\n评论"
@@ -85,6 +95,15 @@ def test_description_property(meta):
     assert clone.description == description
 
 
+def test_description_property_empty(meta):
+    clone = meta.clone
+    orig = clone.get_element("//dc:description")
+    orig.delete()
+    description = "评论\nnCommentaires\nComments"
+    clone.description = description
+    assert clone.description == description
+
+
 def test_get_subject(meta):
     subject = meta.get_subject()
     expected = "Sujet de sa majesté"
@@ -105,6 +124,15 @@ def test_subject_property(meta):
     assert clone.subject == subject
 
 
+def test_subject_property_empty(meta):
+    clone = meta.clone
+    orig = clone.get_element("//dc:subject")
+    orig.delete()
+    subject = "Θέμα"
+    clone.subject = subject
+    assert clone.subject == subject
+
+
 def test_get_language(meta):
     language = meta.get_language()
     assert language is None
@@ -667,6 +695,7 @@ def test_get_user_defined_metadata_buggy_meta_name(meta):
         "Achevé à la date": datetime(2009, 7, 31),
         "Numéro du document": Decimal("3"),
         "Vérifié par": "Moi-même",
+        "": True,
     }
     assert metadata == expected
 
@@ -681,6 +710,11 @@ def test_user_defined_metadata_list_buggy_meta_name(meta):
             break
     metadata_list = meta._user_defined_metadata_list()
     expected = [
+        {
+            "meta:name": "",
+            "meta:value-type": "boolean",
+            "value": True,
+        },
         {
             "meta:name": "Achevé à la date",
             "meta:value-type": "date",
@@ -691,7 +725,11 @@ def test_user_defined_metadata_list_buggy_meta_name(meta):
             "meta:value-type": "float",
             "value": Decimal("3"),
         },
-        {"meta:name": "Vérifié par", "meta:value-type": "string", "value": "Moi-même"},
+        {
+            "meta:name": "Vérifié par",
+            "meta:value-type": "string",
+            "value": "Moi-même",
+        },
     ]
     assert metadata_list == expected
 
@@ -700,7 +738,6 @@ def test_user_defined_metadata_list(meta):
     td = timedelta(hours=5)
     meta.set_user_defined_metadata("duration", td)
     metadata_list = meta._user_defined_metadata_list()
-    print(metadata_list)
     expected = [
         {
             "meta:name": "Achevé à la date",
@@ -944,7 +981,6 @@ def test_meta_export_dict_auto_reload_hyperlink_behaviour(meta):
             },
         ],
     }
-    print(exported)
     assert exported == expected
 
 
